==> haskell-stm-chans-3.0.0.9-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-chans
version:              3.0.0.9
visibility:           public
id:                   stm-chans-3.0.0.9-IqHp3U9TgSU647bHSIburu
key:                  stm-chans-3.0.0.9-IqHp3U9TgSU647bHSIburu
license:              BSD-3-Clause
copyright:            2011–2023 wren romano
maintainer:           wren@cpan.org
author:               wren gayle romano, Thomas DuBuisson
stability:            provisional
homepage:             https://wrengr.org/software/hackage.html
synopsis:             Additional types of channels for STM.
description:          Additional types of channels for STM.
category:             Concurrency
abi:                  b5fd55bc7b1eeb27ace00bcef0f4ff39
exposed:              True
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue

import-dirs:          /usr/lib/ghc-9.2.8/site-local/stm-chans-3.0.0.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stm-chans-3.0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-chans
hs-libraries:         HSstm-chans-3.0.0.9-IqHp3U9TgSU647bHSIburu
depends:              base-4.16.4.0 stm-2.5.0.2
haddock-interfaces:   /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html:         /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-chans-3.0.0.9-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-chans
version:              3.0.0.9
visibility:           public
id:                   stm-chans-3.0.0.9-CQu29so2bvC6Kzm6cIERmj
key:                  stm-chans-3.0.0.9-CQu29so2bvC6Kzm6cIERmj
license:              BSD-3-Clause
copyright:            2011–2023 wren romano
maintainer:           wren@cpan.org
author:               wren gayle romano, Thomas DuBuisson
stability:            provisional
homepage:             https://wrengr.org/software/hackage.html
synopsis:             Additional types of channels for STM.
description:          Additional types of channels for STM.
category:             Concurrency
abi:                  5cacc8097a4b2ac2ef2b36939925bc36
exposed:              True
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stm-chans-3.0.0.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stm-chans-3.0.0.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stm-chans-3.0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-chans
hs-libraries:         HSstm-chans-3.0.0.9-CQu29so2bvC6Kzm6cIERmj
depends:              base-4.17.2.1 stm-2.5.1.0
haddock-interfaces:   /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html:         /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
